Luke Smith's Webpage

## 🏞️ In My Network

🎥 Videos
  Or watch them on Odysee or YouTube.
LARBS
  My installable GNU/Linux dotfiles running suckless software on Artix Linux
Not Related!
  My Podcast on numerous actually important topics. See this if new.
Github
  The programs and scripts I maintain for public consumption.
LandChad.net
  A tutorial site to help you set up your own website and self-hosted services.
🍲 Based.Cooking
  A minimalist, adfree and unintrustive recipe website I maintain now.
📚 LindyPress.Net
  Reprinted, reinvigorated and hard-to-find classical and medieval works.

## 📜 Writings

### Recent Articles

- 14 Nov – Important notes for LARBS users
- 03 Sep – Obscenities are symptoms of weak minds.
- 28 Aug – Every Web Browser Absolutely Sucks.
- 13 Aug – Bringing back old-school web pins and buttons
- 29 Jul – Important: LindyPress undergoing some updates
- 23 Jul – YouTube stream now
- 22 Jul – The classical book reprinting site is live! LindyPress.net
- See all other blog posts...

### Topic Cloud

- 💰 Crypto
- 📈 Economics
- 🗣️ Language
- 👨‍👩‍👦 Lifestyle
- 🐃 Linux
- 😎 Personal
- 🎓 Philosophy
- 👑 Politics
- ⛪ Religion
- 🥼 Science
- 🖥️ Software
- ⚙️ Technology
- 📜 Tradition
- 📖 Tutorial
- 🆕 Updates

### Get updates via RSS

    https://lukesmith.xyz/rss.xml
    https://lukesmith.xyz/peertube
    https://odysee.com/$/rss/@Luke/70
    https://notrelated.xyz/rss

## 💸 Donate.

- Donate with a credit/debit card.
- BTC: (QR) bc1qw5w6pxsk3aj324tmqrhhpmpfprxcfxe6qhetuv
- XMR: (QR) 48jewbtxe4jU3MnzJFjTs3gVFWh2nRrAMWdUuUd7Ubo375LL4SjLTnMRKBrXburvEh38QSNLrJy3EateykVCypnm6gcT9bh
- Paypal, Venmo, Uphold or Zelle money to `luke@lukesmith.xyz`

fhsaf-saflhl2.02.1k20 k-l-2.-2ui -kl-23.2ui + =ara=r+ 0 -0010.020900 ah98h90 + 921841= i i iiiiiiiiiiii iiii iiii i lshfal yjlj Thfjsal i_am_here_ _there_was_i_ h24_-u-23.02_09 _ia_y_Y_t_T_n_ 2024-04 2024-04- ::60 2024-04-03 May. 2nd '20 12 12 20 12:42:22+05:00 title 1 value 1 nothing 1 value 2 nothing 2 value 1 nothing 1 value 2 nothing 2 title 2 value 1 nothing 1 value 2 nothing 2 value 1 nothing 1 value 2 nothing 2